#ifndef CLIENTDEPOTUSER_H

#define CLIENTDEPOTUSER_H

#include "listnode.h"
#include "filesys.h"
#include "error.h"
#include "clientuser.h"
#include "p4objects.h"

/* The ClientDepotUser class is a ClientUser that is built to handle "p4 depot" and "p4 depots" *
 * commands.  It stores the data from these commands in public variables that can be accessed   *
 * later. */

class ClientDepotUser : public ClientUser
{
public:
	ClientDepotUser();
	virtual ~ClientDepotUser();
	void OutputInfo(char, const_char *);
	/* Called by Perforce for each line of output.  We put it in the appropriate place based on specflag.*/
	void OutputSpec(const_char *data);
	/* A specially defined function for dumping the depot spec into a StrBuf. */

	ListList depots;
	/* After "p4 depots" is called, this will be a list of StrBufs that hold depot names. */
	StrBuf spec;
	/* If "p4 depot -o" is called, this will hold the entire spec. */
	BOOL specflag;
	/* Set this flag before calling a command, so this object knows how to treat the output. */
	short results;
	/* This is how we keep track of whether we've created more than MAXRESULTS depots and should stop. */
};

#endif